@@ -1,7 +1,7 @@
 import logging
 
 import discord
-from ddtrace import tracer
+from ddtrace.trace import tracer
 from discord import app_commands
 from discord.ext import commands
 
