@@ -1,10 +1,12 @@
-"""Support extra message content
+"""
+Support extra message content.
 
 Revision ID: c03099407b40
 Revises: 01766a5fb976
 Create Date: 2023-09-04 19:39:19.981210
 
 """
+
 import sqlalchemy as sa
 from alembic import op
 
@@ -15,9 +17,9 @@ branch_labels = None
 depends_on = None
 
 
-def upgrade():
+def upgrade() -> None:
     op.add_column("channels", sa.Column("extra", sa.String(length=255), nullable=True))
 
 
-def downgrade():
+def downgrade() -> None:
     op.drop_column("channels", "extra")
