@@ -1,10 +1,12 @@
-"""Move points config to channel
+"""
+Move points config to channel.
 
 Revision ID: fd7ff2703f57
 Revises: a1caf292fe93
 Create Date: 2022-11-02 16:41:33.747604
 
 """
+
 import sqlalchemy as sa
 from alembic import op
 
@@ -15,7 +17,7 @@ branch_labels = None
 depends_on = None
 
 
-def upgrade():
+def upgrade() -> None:
     op.add_column(
         "channels",
         sa.Column("show_points", sa.Boolean(), server_default=sa.text("false"), nullable=False),
@@ -31,7 +33,7 @@ def upgrade():
     op.drop_column("guilds", "show_points")
 
 
-def downgrade():
+def downgrade() -> None:
     op.add_column(
         "guilds",
         sa.Column(
