@@ -3,7 +3,7 @@ from __future__ import annotations
 from typing import TYPE_CHECKING, TypeVar
 
 import discord
-from ddtrace import tracer
+from ddtrace.trace import tracer
 from discord import ui
 
 from spellbot.metrics import add_span_context
@@ -108,59 +108,3 @@ class StartedGameSelect(ui.Select[T]):
                 original_response = await safe_original_response(interaction)
                 if original_response:
                     await action.add_points(original_response, points)
-
-
-class StartedGameSelectWinLoss(ui.Select[T]):
-    def __init__(self, bot: SpellBot) -> None:
-        self.bot = bot
-        super().__init__(
-            custom_id="points",
-            placeholder="Report game outcome",
-            options=[
-                discord.SelectOption(label="Loss", value="0", emoji="❤️‍🩹"),
-                discord.SelectOption(label="Tie", value="1", emoji="🏅"),
-                discord.SelectOption(label="Win", value="3", emoji="🏆"),
-            ],
-        )
-
-    async def callback(self, interaction: discord.Interaction) -> None:
-        from spellbot.actions import LookingForGameAction
-
-        with tracer.trace(name="interaction", resource="points"):
-            add_span_context(interaction)
-            await safe_defer_interaction(interaction)
-            assert interaction.original_response
-            points = int(self.values[0])
-            async with LookingForGameAction.create(self.bot, interaction) as action:
-                original_response = await safe_original_response(interaction)
-                if original_response:
-                    await action.add_points(original_response, points)
-
-
-class StartedGameViewWithConfirm(BaseView):
-    def __init__(self, bot: SpellBot) -> None:
-        super().__init__(bot)
-        self.add_item(StartedGameSelectWinLoss[StartedGameViewWithConfirm](self.bot))
-        self.add_item(StartedGameConfirm[StartedGameViewWithConfirm](self.bot))
-
-
-class StartedGameConfirm(ui.Button[T]):
-    def __init__(self, bot: SpellBot) -> None:
-        self.bot = bot
-        super().__init__(
-            custom_id="confirm",
-            emoji="✔️",
-            label="Confirm points",
-            style=discord.ButtonStyle.blurple,
-        )
-
-    async def callback(self, interaction: discord.Interaction) -> None:
-        from spellbot.actions import LookingForGameAction
-
-        with tracer.trace(name="interaction", resource="confirm"):
-            add_span_context(interaction)
-            await safe_defer_interaction(interaction)
-            async with LookingForGameAction.create(self.bot, interaction) as action:
-                original_response = await safe_original_response(interaction)
-                if original_response:
-                    await action.confirm_points(original_response)
